@@ -41,5 +41,6 @@ class MysqlPool(BaseConnectionPool):
                         passwd=self.conn_info.password, db=self.conn_info.db_name,
                         mincached=self.conn_info.min_size, blocking=False, maxusage=self.conn_info.min_size,
                         maxshared=self.conn_info.max_size, maxcached=self.conn_info.max_size,
-                        ping=1, maxconnections=self.conn_info.max_size, charset="utf8mb4", autocommit=True)
+                        ping=1, maxconnections=self.conn_info.max_size, charset="utf8mb4", autocommit=True,
+                        read_timeout=30)
         return pool
